dto

package
v0.0.0-...-51b3333 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CampaignType

type CampaignType int64
const (
	CampaignTypeEmail                   CampaignType = 1
	CampaignTypeSMS                     CampaignType = 2
	CampaignTypeDeleted                 CampaignType = 4
	CampaignTypeNormalApproved          CampaignType = 5
	CampaignTypeIncomingSMS             CampaignType = 6
	CampaignTypeSMSWithOADC             CampaignType = 8
	CampaignTypeEmailWithAttachement    CampaignType = 14
	CampaignTypeEmailSubdelivey         CampaignType = 16
	CampaignTypeEmailMasterDelivery     CampaignType = 17
	CampaignTypeSMSLinkMobilityDelivery CampaignType = 18
	CampaignTypeAppPushAndroidDelivery  CampaignType = 19
	CampaignTypeAppPushIOSDelivery      CampaignType = 20
	CampaignTypeAppPushWindowsDelivery  CampaignType = 21
)

type CampaignVersionDTO

type CampaignVersionDTO struct {
	CampaignID     int64   `json:"campaignId"`
	CampaignName   string  `json:"campaignName"`
	CampaignTypeID int64   `json:"campaignTypeId"`
	Active         bool    `json:"active"`
	Locked         bool    `json:"locked"`
	DateCreated    int64   `json:"dateCreated"`
	DateModified   int64   `json:"dateModified"`
	UserCreated    string  `json:"userCreated"`
	UserModified   string  `json:"userModified"`
	Stats          StatDTO `json:"statDtos"`
	LastActivated  int64   `json:"lastActivated"`
}

type ChannelType

type ChannelType int64
const (
	ChannelTypeUnknown ChannelType = 0
	ChannelTypeEmail   ChannelType = 1
	ChannelTypeSMS     ChannelType = 2
	ChannelTypePush    ChannelType = 3
	ChannelTypeMixed   ChannelType = 4
)

type ContactDTO

type ContactDTO struct {
	ID                        int64             `json:"id,omitempty"`
	ListID                    int64             `json:"listId"`
	Country                   string            `json:"country,omitempty"`
	OriginalID                string            `json:"originalId"`
	OriginalIDHashed          int64             `json:"originalIDHashed,omitempty"`
	FirstName                 string            `json:"firstName,omitempty"`
	LastName                  string            `json:"lastName,omitempty"`
	MiddleName                string            `json:"middleName,omitempty"`
	EmailAddress              string            `json:"emailAddress,omitempty"`
	Title                     string            `json:"title,omitempty"`
	DateOfBirth               string            `json:"dateOfBirth,omitempty"`
	City                      string            `json:"city,omitempty"`
	ZipCode                   string            `json:"zipcode,omitempty"`
	Sex                       string            `json:"sex,omitempty"`
	MobileNumber              string            `json:"mobileNumber,omitempty"`
	Unsubscribed              bool              `json:"unsubscribed"`
	Bounced                   bool              `json:"bounced"`
	MobileUnsubscribed        bool              `json:"mobileUnsubscribed"`
	AudioUnsubscribed         bool              `json:"audioUnsubscribed"`
	PreferredContentVersionID int64             `json:"preferredContentVersionId,omitempty"`
	OptOutDate                int64             `json:"optOutDate"`
	DateOfInvalidation        int64             `json:"dateOfInvalidation"`
	OptOutMobileDate          int64             `json:"optOutMobileDate"`
	OptOutAudioDate           int64             `json:"optOutAudioDate"`
	Active                    bool              `json:"active"`
	DateCreated               int64             `json:"dateCreated,omitempty"`
	DateModified              int64             `json:"dateModified,omitempty"`
	BlockedUntil              int64             `json:"blockedUntil,omitempty"`
	Properties                map[string]string `json:"properties,omitempty"`
	NamedProperties           map[string]string `json:"namedProperties,omitempty"`
	MobileNumberValid         bool              `json:"mobileNumberValid,omitempty"`
}

type DataType

type DataType string
const (
	DataTypeString   DataType = "STRING"
	DataTypeInteger  DataType = "INTEGER"
	DataTypeBigInt   DataType = "BIGINT"
	DataTypeDateTime DataType = "DATETIME"
)

type MessageDTO

type MessageDTO struct {
	Message string `json:"message"`
}

type PropertyDTO

type PropertyDTO struct {
	ID                int64        `json:"id"`
	PropertyTypeID    PropertyType `json:"propertyTypeId"` // type of property
	Name              string       `json:"name"`
	Description       string       `json:"description,omitempty"`
	DataType          DataType     `json:"dataType,omitempty"`          // Data type to use for this property in Business Analytics export. Null means 'default', i.e. interpret value as a string
	IncludeInBaExport bool         `json:"includeInBaExport,omitempty"` // Whether this property should be included in Business Analytics export. Defaults to false
	DateCreated       int64        `json:"dateCreated"`                 // read only, populated by server
	DateModified      int64        `json:"dateModified"`                // read only, populated by server
	UserCreated       string       `json:"userCreated"`                 // read only, populated by server
	UserModified      string       `json:"userModified"`                // read only, populated by server
	StaticProperty    bool         `json:"staticProperty"`              // is this a static property
	FileHeaders       []string     `json:"fileHeaders,omitempty"`
}

type PropertyType

type PropertyType int64
const (
	PropertyTypeEndUser   PropertyType = 1
	PropertyTypeEncrypted PropertyType = 1
	PropertyTypeDeleted   PropertyType = 1
)

type SendTriggerDTO

type SendTriggerDTO struct {
	DeliveryTime                 string            `json:"deliveryTime,omitempty"` // When is the trigger to be sent? Trigger will be sent immediately if the value is omitted, format shall be yyyy-MM-ddTHH:mm:ss-zzzz -zzzz is timezone difference from UCT sweden is +01000 , e.g. 2016-02-09T11:00:00+0100,
	OptOut                       bool              `json:"optOut,omitempty"`       // if true the user will unsubscribed,
	SaveProps                    bool              `json:"saveProps,omitempty"`    // True to update propertydata on the contact,
	OriginalId                   string            `json:"originalId"`             // originalId of the contact the trigger is to be sent to,
	CustomerId                   int64             `json:"customerId"`
	CampaignId                   int64             `json:"campaignId,omitempty"`                   // If supplied the trigger willsend this delivery instead of the triggers active delivery,
	Properties                   map[string]string `json:"properties"`                             // the data for the trigger,
	ForceCreateMissingProperties bool              `json:"forceCreateMissingProperties,omitempty"` // Automatically create missing properties. If false, missing property names will throw exception
}

type StatDTO

type StatDTO struct {
	ID              int64   `json:"id"`
	DeliveryID      int64   `json:"deliveryId"`
	Source          int64   `json:"source"`
	ProjectID       int64   `json:"projectId"`
	DeliveryTypeID  int64   `json:"deliveryTypeId"`
	Recipients      int64   `json:"recipients"`
	Sent            int64   `json:"sent"`
	Opened          int64   `json:"opened"`
	Clicked         int64   `json:"clicked"`
	OpenedInBrowser int64   `json:"openedInBrower"`
	NonDeliverable  int64   `json:"nonDeliverable"`
	Unsubscribe     int64   `json:"unsubscribed"`
	NotBounced      int64   `json:"notBounced"`
	SoftBounced     int64   `json:"softBounced"`
	HardBounced     int64   `json:"hardBounced"`
	Complaints      int64   `json:"complaints"`
	ShareTarget     int64   `json:"shareTarget"`
	MailClick       int64   `json:"mailClick"`
	Conversions     int64   `json:"conversions"`
	UniqueClick     int64   `json:"uniqueClick"`
	Amount          float64 `json:"amount"`
}

type TriggerDTO

type TriggerDTO struct {
	ID               int64                `json:"id"`
	Type             int64                `json:"type"`
	ProjectID        int64                `json:"projectId"`
	Name             string               `json:"name"`
	Description      string               `json:"description,omitempty"`
	ListID           int64                `json:"listId"`
	DateCreated      int64                `json:"dateCreated,omitempty"`
	DateModified     int64                `json:"dateModified,omitempty"`
	UserCreated      string               `json:"userCreated,omitempty"`
	UserModified     string               `json:"userModified,omitempty"`
	ChannelTypeID    ChannelType          `json:"channelTypeId"`
	ActiveCampaign   int64                `json:"activeCampaign"`
	IgnoreOptOut     bool                 `json:"ignoreOptOut,omitempty"`
	CampaignVersions []CampaignVersionDTO `json:"campaignVersions,omitempty"`
	Active           bool                 `json:"active,omitempty"`
}

Jump to